"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepActorFollow = void 0;
const trotsky_1 = require("../trotsky");
/**
 * Represents a step that performs an actor follow operation using the agent.
 * @typeParam P - Type of the parent step, extending {@link StepActor}.
 * @typeParam C - Type of the context object, extending {@link StepActorOutput}.
 * @typeParam O - Type of the output object.
 * @public
 */
class StepActorFollow extends trotsky_1.Step {
    /**
     * Applies the step by performing a follow operation.
     * Requires the context to provide the `did` of the actor to follow.
     * @throws
     * Error if no context is found.
     */
    async apply() {
        if (!this.context) {
            throw new Error("No context found for StepActorFollow");
        }
        await this.agent.follow(this.context.did);
    }
}
exports.StepActorFollow = StepActorFollow;
//# sourceMappingURL=StepActorFollow.js.map