import type { AppBskyGraphGetFollowers } from "@atproto/api";
import { StepActors, type StepActor, type StepActorOutput } from "../trotsky";
/**
 * Type representing the output of the followers retrieved by {@link StepActorFollowers}.
 * @public
 */
export type StepActorFollowersOutput = AppBskyGraphGetFollowers.OutputSchema["followers"];
/**
 * Type representing the query parameters for retrieving followers.
 * @public
 */
export type StepActorFollowersQueryParams = AppBskyGraphGetFollowers.QueryParams;
/**
 * Type representing the cursor for paginated queries.
 * @public
 */
export type StepActorFollowersQueryParamsCursor = StepActorFollowersQueryParams["cursor"] | undefined;
/**
 * Represents a step for retrieving an actor's followers using the Bluesky API.
 * Supports paginated retrieval of followers.
 * @typeParam P - Type of the parent step, extending {@link StepActor}.
 * @typeParam C - Type of the context object, extending {@link StepActorOutput}.
 * @typeParam O - Type of the output object, extending {@link StepActorFollowersOutput}.
 * @public
 */
export declare class StepActorFollowers<P = StepActor, C extends StepActorOutput = StepActorOutput, O extends StepActorFollowersOutput = StepActorFollowersOutput> extends StepActors<P, C, O> {
    /**
     * Applies pagination to retrieve followers and sets the output.
     * Fetches paginated results using the agent and appends them to the output.
     */
    applyPagination(): Promise<void>;
    /**
     * Generates query parameters for retrieving followers, including the optional cursor.
     * @param cursor - The cursor for paginated queries.
     * @returns The query parameters for retrieving followers.
     * @throws
     * Error if no context is found.
     */
    private queryParams;
}
//# sourceMappingURL=StepActorFollowers.d.ts.map