"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepActorFollowers = void 0;
const trotsky_1 = require("../trotsky");
/**
 * Represents a step for retrieving an actor's followers using the Bluesky API.
 * Supports paginated retrieval of followers.
 * @typeParam P - Type of the parent step, extending {@link StepActor}.
 * @typeParam C - Type of the context object, extending {@link StepActorOutput}.
 * @typeParam O - Type of the output object, extending {@link StepActorFollowersOutput}.
 * @public
 */
class StepActorFollowers extends trotsky_1.StepActors {
    /**
     * Applies pagination to retrieve followers and sets the output.
     * Fetches paginated results using the agent and appends them to the output.
     */
    async applyPagination() {
        this.output = await this.paginate("followers", (cursor) => {
            return this.agent.app.bsky.graph.getFollowers(this.queryParams(cursor));
        });
    }
    /**
     * Generates query parameters for retrieving followers, including the optional cursor.
     * @param cursor - The cursor for paginated queries.
     * @returns The query parameters for retrieving followers.
     * @throws
     * Error if no context is found.
     */
    queryParams(cursor) {
        if (!this.context) {
            throw new Error("No context found for StepActorFollowers");
        }
        return { "actor": this.context.did, cursor };
    }
}
exports.StepActorFollowers = StepActorFollowers;
//# sourceMappingURL=StepActorFollowers.js.map