"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepActorFollowings = void 0;
const trotsky_1 = require("../trotsky");
/**
 * Represents a step for retrieving an actor's followings using the Bluesky API.
 * Supports paginated retrieval of followings.
 * @typeParam P - Type of the parent step, extending {@link StepActor}.
 * @typeParam C - Type of the context object, extending {@link StepActorOutput}.
 * @typeParam O - Type of the output object, extending {@link StepActorFollowingsOutput}.
 * @public
 */
class StepActorFollowings extends trotsky_1.StepActors {
    /**
     * Applies pagination to retrieve followings and sets the output.
     * Fetches paginated results using the agent and appends them to the output.
     */
    async applyPagination() {
        this.output = await this.paginate("follows", (cursor) => {
            return this.agent.app.bsky.graph.getFollows(this.queryParams(cursor));
        });
    }
    /**
     * Generates query parameters for retrieving followings, including the optional cursor.
     * @param cursor - The cursor for paginated queries.
     * @returns The query parameters for retrieving followings.
     * @throws
     * Error if no context is found.
     */
    queryParams(cursor) {
        if (!this.context) {
            throw new Error("No context found for StepActorFollowings");
        }
        return { "actor": this.context.did, cursor };
    }
}
exports.StepActorFollowings = StepActorFollowings;
//# sourceMappingURL=StepActorFollowings.js.map