import type { AppBskyFeedGetActorLikes } from "@atproto/api";
import { StepPosts, type StepPostsOutput, type StepActor, type StepActorOutput } from "../trotsky";
/**
 * Type representing the output of the likes retrieved by {@link StepActorLikes}.
 * @public
 */
export type StepActorLikesOutput = StepPostsOutput;
/**
 * Type representing the query parameters for retrieving actor likes.
 * @public
 */
export type StepActorLikesQueryParams = AppBskyFeedGetActorLikes.QueryParams;
/**
 * Type representing the cursor for paginated queries.
 * @public
 */
export type StepActorLikesQueryParamsCursor = StepActorLikesQueryParams["cursor"] | undefined;
/**
 * Represents a step for retrieving an actor's likes using the Bluesky API.
 * Supports paginated retrieval of likes.
 * @typeParam P - Type of the parent step, extending {@link StepActor}.
 * @typeParam C - Type of the context object, extending {@link StepActorOutput}.
 * @typeParam O - Type of the output object, extending {@link StepActorLikesOutput}.
 * @public
 */
export declare class StepActorLikes<P = StepActor, C extends StepActorOutput = StepActorOutput, O extends StepActorLikesOutput = StepActorLikesOutput> extends StepPosts<P, C, O> {
    /**
     * Applies pagination to retrieve likes and sets the output.
     * Fetches paginated results using the agent and appends them to the output.
     */
    applyPagination(): Promise<void>;
    /**
     * Generates query parameters for retrieving likes, including the optional cursor.
     * @param cursor - The cursor for paginated queries.
     * @returns The query parameters for retrieving likes.
     * @throws
     * Error if no context is found.
     */
    queryParams(cursor: StepActorLikesQueryParamsCursor): StepActorLikesQueryParams;
}
//# sourceMappingURL=StepActorLikes.d.ts.map