"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepActorLikes = void 0;
const trotsky_1 = require("../trotsky");
/**
 * Represents a step for retrieving an actor's likes using the Bluesky API.
 * Supports paginated retrieval of likes.
 * @typeParam P - Type of the parent step, extending {@link StepActor}.
 * @typeParam C - Type of the context object, extending {@link StepActorOutput}.
 * @typeParam O - Type of the output object, extending {@link StepActorLikesOutput}.
 * @public
 */
class StepActorLikes extends trotsky_1.StepPosts {
    /**
     * Applies pagination to retrieve likes and sets the output.
     * Fetches paginated results using the agent and appends them to the output.
     */
    async applyPagination() {
        this.output = await this.paginate("feed", (cursor) => {
            return this.agent.app.bsky.feed.getActorLikes(this.queryParams(cursor));
        });
    }
    /**
     * Generates query parameters for retrieving likes, including the optional cursor.
     * @param cursor - The cursor for paginated queries.
     * @returns The query parameters for retrieving likes.
     * @throws
     * Error if no context is found.
     */
    queryParams(cursor) {
        if (!this.context) {
            throw new Error("No context found for StepActorLikes");
        }
        return { "actor": this.context.did, cursor };
    }
}
exports.StepActorLikes = StepActorLikes;
//# sourceMappingURL=StepActorLikes.js.map