"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepActorLists = void 0;
const trotsky_1 = require("../trotsky");
/**
 * Represents step for retrieving the lists associated with a specific actor, extending the {@link StepLists} functionality.
 *
 * @typeParam P - The parent step type, defaulting to {@link StepActor}.
 * @typeParam C - The context type, defaulting to {@link StepActorOutput}.
 * @typeParam O - The output type, defaulting to {@link StepActorListsOutput}.
 *
 * @public
 */
class StepActorLists extends trotsky_1.StepLists {
    /**
     * Applies pagination to retrieve all lists associated with the actor, handling multiple pages of results if necessary.
     *
     * @returns A promise that resolves when pagination is complete.
     */
    async applyPagination() {
        this.output = await this.paginate("lists", (cursor) => {
            return this.agent.app.bsky.graph.getLists(this.queryParams(cursor));
        });
    }
    /**
     * Generates query parameters for retrieving an actor's lists, including the optional cursor.
     *
     * @param cursor - The cursor for paginated queries.
     * @returns The query parameters for retrieving the actor's lists.
     * @throws Error if no context is found.
     */
    queryParams(cursor) {
        if (!this.context) {
            throw new Error("No context found for StepActorLists");
        }
        return { "actor": this.context.did, cursor };
    }
}
exports.StepActorLists = StepActorLists;
//# sourceMappingURL=StepActorLists.js.map