"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepActorPosts = void 0;
const trotsky_1 = require("../trotsky");
/**
 * Represents a step for retrieving an actor's posts using the Bluesky API.
 * Supports paginated retrieval of posts.
 * @typeParam P - Type of the parent step, extending {@link StepActor}.
 * @typeParam C - Type of the context object, extending {@link StepActorOutput}.
 * @typeParam O - Type of the output object, extending {@link StepActorPostsOutput}.
 * @public
 */
class StepActorPosts extends trotsky_1.StepPosts {
    /**
     * Applies pagination to retrieve posts and sets the output.
     * Fetches paginated results using the agent and appends them to the output.
     */
    async applyPagination() {
        const feed = await this.paginate("feed", (cursor) => {
            return this.agent.app.bsky.feed.getAuthorFeed(this.queryParams(cursor));
        });
        this.output = feed.map((post) => post.post);
    }
    /**
     * Generates query parameters for retrieving posts, including the optional cursor.
     * @param cursor - The cursor for paginated queries.
     * @returns The query parameters for retrieving posts.
     * @throws
     * Error if no context is found.
     */
    queryParams(cursor) {
        if (!this.context) {
            throw new Error("No context found for StepActorPosts");
        }
        return { "actor": this.context.did, cursor };
    }
}
exports.StepActorPosts = StepActorPosts;
//# sourceMappingURL=StepActorPosts.js.map