"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepActorStreamPosts = void 0;
const trotsky_1 = require("../trotsky");
const jetstream_1 = require("./utils/jetstream");
/**
 * @experimental
 *
 * A specialized step that extends {@link StepStreamPosts} to stream an actor's posts.
 * It uses a Jetstream-based event emitter filtered by the actor's DID.
 *
 * @typeParam P - The parent type of this step.
 * @typeParam C - The context or child output type, extending {@link StepActorOutput}.
 * @typeParam O - The final output type of this step, defaulting to {@link StepActorStreamPostsOutput}.
 */
class StepActorStreamPosts extends trotsky_1.StepStreamPosts {
    /**
     * Provides an event emitter that listens for "app.bsky.feed.post" events associated with this actor.
     * Throws an error if no context (i.e., actor DID) is available.
     *
     * @returns A promise resolving to the Jetstream event emitter.
     */
    async buildEventEmitter() {
        if (!this.context) {
            throw new Error("No context found for StepActorStreamPosts");
        }
        return (0, jetstream_1.buildEventEmitter)(["app.bsky.feed.post"], [this.context.did]);
    }
}
exports.StepActorStreamPosts = StepActorStreamPosts;
//# sourceMappingURL=StepActorStreamPosts.js.map