import { Step, type StepActor, type StepActorOutput } from "../trotsky";
/**
 * Represents step that unblocks the current actor (if blocked).
 *
 * @typeParam P - The parent step type, defaulting to {@link StepActor}.
 * @typeParam C - The context or child output type, defaulting to {@link StepActorOutput}.
 * @typeParam O - The output type produced by this step, defaulting to `null`.
 * @public
 */
export declare class StepActorUnblock<P = StepActor, C extends StepActorOutput = StepActorOutput, O = null> extends Step<P, C, O> {
    /**
     * Applies the unblock logic:
     * 1. Retrieves the current block list.
     * 2. Checks if the actor is actually blocked.
     * 3. If blocked, deletes the block record to unblock the actor.
     *
     * @throws Error
     * If no context is available for the step, indicating the actor is unknown.
     */
    apply(): Promise<void>;
}
//# sourceMappingURL=StepActorUnblock.d.ts.map