"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepActorUnblock = void 0;
const api_1 = require("@atproto/api");
const matchProperty_1 = __importDefault(require("./utils/matchProperty"));
const trotsky_1 = require("../trotsky");
/**
 * Represents step that unblocks the current actor (if blocked).
 *
 * @typeParam P - The parent step type, defaulting to {@link StepActor}.
 * @typeParam C - The context or child output type, defaulting to {@link StepActorOutput}.
 * @typeParam O - The output type produced by this step, defaulting to `null`.
 * @public
 */
class StepActorUnblock extends trotsky_1.Step {
    /**
     * Applies the unblock logic:
     * 1. Retrieves the current block list.
     * 2. Checks if the actor is actually blocked.
     * 3. If blocked, deletes the block record to unblock the actor.
     *
     * @throws Error
     * If no context is available for the step, indicating the actor is unknown.
     */
    async apply() {
        if (!this.context) {
            throw new Error("No context found for StepActorUnblock");
        }
        const { "data": { blocks } } = await this.agent.app.bsky.graph.getBlocks();
        const block = blocks.find((0, matchProperty_1.default)("did", this.context.did));
        // If the block does not exist, there is nothing to do
        if (!block?.viewer?.blocking)
            return;
        const repo = this.agent.did;
        const { rkey } = new api_1.AtUri(block.viewer.blocking);
        await this.agent.app.bsky.graph.block.delete({ repo, rkey });
    }
}
exports.StepActorUnblock = StepActorUnblock;
//# sourceMappingURL=StepActorUnblock.js.map