import { Step, StepActor, type StepActorOutput } from "../trotsky";
/**
 * Represents step that unfollows the current actor (if followed).
 *
 * @typeParam P - The parent step type, defaulting to {@link StepActor}.
 * @typeParam C - The context or child output type, defaulting to {@link StepActorOutput}.
 * @typeParam O - The output type produced by this step, defaulting to `null`.
 * @public
 */
export declare class StepActorUnfollow<P = StepActor, C extends StepActorOutput = StepActorOutput, O = null> extends Step<P, C, O> {
    /**
     * Applies the unfollow logic:
     * 1. Retrieves the current actor's relationship with the specified context actor.
     * 2. Checks if the current actor is indeed following the specified context actor.
     * 3. If so, calls the API to remove the follow relationship.
     *
     * @throws Error
     * If no context is available for the step, indicating the actor is unknown.
     */
    apply(): Promise<void>;
}
//# sourceMappingURL=StepActorUnfollow.d.ts.map