"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepListMembers = void 0;
const trotsky_1 = require("../trotsky");
/**
 * Represents step for retrieving the members of a specific list, extending the {@link StepActors} functionality.
 *
 * @typeParam P - The parent step type, defaulting to {@link StepList}.
 * @typeParam C - The context type, defaulting to {@link StepListOutput}.
 * @typeParam O - The output type, defaulting to {@link StepListMembersOutput}.
 *
 * @public
 */
class StepListMembers extends trotsky_1.StepActors {
    /**
     * Applies pagination to retrieve all members of the list, handling multiple pages of results if necessary.
     *
     * @returns A promise that resolves when pagination is complete.
     */
    async applyPagination() {
        const items = await this.paginate("items", (cursor) => {
            return this.agent.app.bsky.graph.getList(this.queryParams(cursor));
        });
        this.output = items.map((item) => item.subject);
    }
    /**
     * Generates query parameters for retrieving a list and its members, including the optional cursor.
     *
     * @param cursor - The cursor for paginated queries.
     * @returns The query parameters for retrieving the list.
     * @throws Error if no context is found.
     */
    queryParams(cursor) {
        if (!this.context) {
            throw new Error("No context found for StepListMembers");
        }
        return { "list": this.context.uri, cursor };
    }
}
exports.StepListMembers = StepListMembers;
//# sourceMappingURL=StepListMembers.js.map