"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepLists = void 0;
const trotsky_1 = require("../trotsky");
/**
 * Abstract class representing a list of Lists to process.
 *
 * @typeParam P - The parent type of this step, defaulting to {@link StepBuilder}.
 * @typeParam C - The child context type, defaulting to `null`.
 * @typeParam O - The output type, defaulting to {@link StepListsOutput}.
 * @public
 */
class StepLists extends trotsky_1.StepBuilderList {
    /**
     * Holds the list of steps to be executed for each List entry.
     */
    _steps = [];
    /**
     * Appends a new List entry step to the current list and returns it.
     *
     * @param iterator - Optional iterator function to be executed for each item in the list.
     * @returns The newly appended {@link StepListsEntry} instance.
     */
    each(iterator) {
        return this.withIterator(iterator).append((trotsky_1.StepListsEntry));
    }
}
exports.StepLists = StepLists;
//# sourceMappingURL=StepLists.js.map