"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepPostAuthor = void 0;
const trotsky_1 = require("../trotsky");
/**
 * Represents a step for retrieving the profile of the author of a specific post.
 * Extends {@link StepActor} to reuse actor-related logic.
 *
 * @typeParam P - The parent type of this step, defaulting to {@link StepPost}.
 * @typeParam C - The context type, defaulting to {@link StepPostOutput}.
 * @typeParam O - The output type, defaulting to {@link StepPostAuthorOutput}.
 * @public
 */
class StepPostAuthor extends trotsky_1.StepActor {
    /**
     * Applies the step logic to retrieve the profile of the author of the post.
     *
     * @throws Error
     * If no context is available for the step, indicating the post is unknown.
     */
    async apply() {
        if (!this.context) {
            throw new Error("No context found for StepPostAuthor");
        }
        const actor = this.context.author.did;
        const { data } = await this.agent.getProfile({ actor });
        this.output = data;
    }
}
exports.StepPostAuthor = StepPostAuthor;
//# sourceMappingURL=StepPostAuthor.js.map