"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepPostRepost = void 0;
const trotsky_1 = require("../trotsky");
/**
 * Represents a step for reposting a specific post.
 *
 * @typeParam P - The parent type of this step, defaulting to {@link StepPost}.
 * @typeParam C - The context type, defaulting to {@link StepPostOutput}.
 * @typeParam O - The output type, defaulting to {@link StepPostRepostOutput}.
 * @public
 */
class StepPostRepost extends trotsky_1.Step {
    /**
     * Applies the step logic to repost the post provided in the context.
     * The resulting URI and CID of the repost are stored in the output.
     *
     * @override
     * @throws Error
     * If the context does not provide the required `uri` and `cid`.
     */
    async apply() {
        const { uri, cid } = this.context;
        this.output = await this.agent.repost(uri, cid);
    }
}
exports.StepPostRepost = StepPostRepost;
//# sourceMappingURL=StepPostRepost.js.map