import type { AtpAgent } from "@atproto/api";
import { Step, type StepBuilder } from "../trotsky";
/**
 * Type representing the path of the JSON file to save the output.
 * @public
 */
export type StepSavePath = string | null;
/**
 * A step
 *
 * @typeParam P - The parent type of this step, defaulting to {@link StepBuilder}.
 * @typeParam C - The context type, defaulting to `null`.
 * @typeParam O - The output type, defaulting to `string`.
 * @public
 */
export declare class StepSave<P = StepBuilder, C = null, O = string> extends Step<P, C, O> {
    /**
     * Path of the JSON file to save the current output.
     */
    protected _path: StepSavePath;
    /**
     * Initializes the StepSave instance with the given path.
     *
     * @param agent - The AT protocol agent used for API calls.
     * @param parent - The parent step in the chain.
     * @param path - The path of the JSON file to save the output. If not provided, the file path will be created using the current timestamp.
     */
    constructor(agent: AtpAgent, parent: P, path?: StepSavePath);
    /**
     * Clones the current step and returns a new instance with the same parameters.
     * @param rest - Additional parameters to pass to the cloned step. This is useful for child class overriding the clone.
     * @returns A new {@link StepActor} instance.
     */
    clone(...rest: unknown[]): this;
    /**
     * Applies the step logic to save the output to a JSON file.
     *
     * @override
     */
    apply(): Promise<void>;
}
//# sourceMappingURL=StepSave.d.ts.map