"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepSave = void 0;
const promises_1 = __importDefault(require("fs/promises"));
const trotsky_1 = require("../trotsky");
/**
 * A step
 *
 * @typeParam P - The parent type of this step, defaulting to {@link StepBuilder}.
 * @typeParam C - The context type, defaulting to `null`.
 * @typeParam O - The output type, defaulting to `string`.
 * @public
 */
class StepSave extends trotsky_1.Step {
    /**
     * Path of the JSON file to save the current output.
     */
    _path = null;
    /**
     * Initializes the StepSave instance with the given path.
     *
     * @param agent - The AT protocol agent used for API calls.
     * @param parent - The parent step in the chain.
     * @param path - The path of the JSON file to save the output. If not provided, the file path will be created using the current timestamp.
     */
    constructor(agent, parent, path = null) {
        super(agent, parent);
        this._path = path;
    }
    /**
     * Clones the current step and returns a new instance with the same parameters.
     * @param rest - Additional parameters to pass to the cloned step. This is useful for child class overriding the clone.
     * @returns A new {@link StepActor} instance.
     */
    clone(...rest) {
        return super.clone(this._path, ...rest);
    }
    /**
     * Applies the step logic to save the output to a JSON file.
     *
     * @override
     */
    async apply() {
        const path = (this._path ?? `Output (${Date.now()})`).replace(/(\.json)?$/, ".json");
        await promises_1.default.writeFile(path, JSON.stringify(this.context));
        this.output = path;
    }
}
exports.StepSave = StepSave;
//# sourceMappingURL=StepSave.js.map