import { Step, StepActorFollowers, StepActorFollowings, StepActorLists, StepActorLikes, StepActorPosts, StepActorStreamPosts } from "../../trotsky";
/**
 * A mixin class providing reusable actor-related methods to extend step functionality.
 * These methods append specific actor-related steps to the current chain.
 *
 * @typeParam P - The parent step type.
 * @typeParam C - The context type.
 * @typeParam O - The output type.
 *
 * @public
 */
export declare abstract class ActorMixins<P, C, O> extends Step<P, C, O> {
    /**
     * Appends a step to fetch the followers of the current actor.
     *
     * @returns The appended {@link StepActorFollowers} instance.
     */
    followers(): StepActorFollowers<this>;
    /**
     * Appends a step to fetch the followings of the current actor.
     *
     * @returns The appended {@link StepActorFollowings} instance.
     */
    followings(): StepActorFollowings<this>;
    /**
     * Appends a step to fetch the liked posts of the current actor.
     *
     * @returns The appended {@link StepActorLikes} instance.
     */
    likes(): StepActorLikes<this>;
    /**
     * Appends a step to fetch the lists of the current actor.
     *
     * @returns The appended {@link StepActorLists} instance.
     */
    lists(): StepActorLists<this>;
    /**
     * Appends a step to fetch the posts of the current actor.
     *
     * @returns The appended {@link StepActorPosts} instance.
     */
    posts(): StepActorPosts<this>;
    /**
     * Appends a step to stream the posts of the current actor.
     *
     * @typeParam T - The type of the stream posts step, defaulting to {@link StepActorStreamPosts}.
     * @returns The appended {@link StepActorStreamPosts} instance.
     */
    streamPosts<T = StepActorStreamPosts<this>>(): T;
    /**
     * Appends a step to block the current actor.
     *
     * @returns The current instance for method chaining.
     */
    block(): this;
    /**
     * Appends a step to unblock the current actor.
     *
     * @returns The current instance for method chaining.
     */
    unblock(): this;
    /**
     * Appends a step to follow the current actor.
     *
     * @returns The current instance for method chaining.
     */
    follow(): this;
    /**
     * Appends a step to unfollow the current actor.
     *
     * @returns The current instance for method chaining.
     */
    unfollow(): this;
}
//# sourceMappingURL=ActorMixins.d.ts.map