"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActorMixins = void 0;
const trotsky_1 = require("../../trotsky");
/**
 * A mixin class providing reusable actor-related methods to extend step functionality.
 * These methods append specific actor-related steps to the current chain.
 *
 * @typeParam P - The parent step type.
 * @typeParam C - The context type.
 * @typeParam O - The output type.
 *
 * @public
 */
class ActorMixins extends trotsky_1.Step {
    /**
     * Appends a step to fetch the followers of the current actor.
     *
     * @returns The appended {@link StepActorFollowers} instance.
     */
    followers() {
        return this.append((trotsky_1.StepActorFollowers));
    }
    /**
     * Appends a step to fetch the followings of the current actor.
     *
     * @returns The appended {@link StepActorFollowings} instance.
     */
    followings() {
        return this.append((trotsky_1.StepActorFollowings));
    }
    /**
     * Appends a step to fetch the liked posts of the current actor.
     *
     * @returns The appended {@link StepActorLikes} instance.
     */
    likes() {
        return this.append((trotsky_1.StepActorLikes));
    }
    /**
     * Appends a step to fetch the lists of the current actor.
     *
     * @returns The appended {@link StepActorLists} instance.
     */
    lists() {
        return this.append((trotsky_1.StepActorLists));
    }
    /**
     * Appends a step to fetch the posts of the current actor.
     *
     * @returns The appended {@link StepActorPosts} instance.
     */
    posts() {
        return this.append((trotsky_1.StepActorPosts));
    }
    /**
     * Appends a step to stream the posts of the current actor.
     *
     * @typeParam T - The type of the stream posts step, defaulting to {@link StepActorStreamPosts}.
     * @returns The appended {@link StepActorStreamPosts} instance.
     */
    streamPosts() {
        return this.append((trotsky_1.StepActorStreamPosts));
    }
    /**
     * Appends a step to block the current actor.
     *
     * @returns The current instance for method chaining.
     */
    block() {
        this.append((trotsky_1.StepActorBlock));
        return this;
    }
    /**
     * Appends a step to unblock the current actor.
     *
     * @returns The current instance for method chaining.
     */
    unblock() {
        this.append((trotsky_1.StepActorUnblock));
        return this;
    }
    /**
     * Appends a step to follow the current actor.
     *
     * @returns The current instance for method chaining.
     */
    follow() {
        this.append((trotsky_1.StepActorFollow));
        return this;
    }
    /**
     * Appends a step to unfollow the current actor.
     *
     * @returns The current instance for method chaining.
     */
    unfollow() {
        this.append((trotsky_1.StepActorUnfollow));
        return this;
    }
}
exports.ActorMixins = ActorMixins;
//# sourceMappingURL=ActorMixins.js.map