"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PostMixins = void 0;
const trotsky_1 = require("../../trotsky");
/**
 * A mixin class providing reusable post-related methods to extend step functionality.
 * These methods append specific post-related steps to the current chain.
 *
 * @typeParam P - The parent type of this step.
 * @typeParam C - The context type.
 * @typeParam O - The output type.
 * @public
 */
class PostMixins extends trotsky_1.Step {
    /**
     * Appends a step to reply to the current post.
     *
     * @param record - The parameters for the reply, which may be resolved at runtime.
     * @returns The appended {@link StepPostReply} instance.
     */
    reply(record) {
        return this.append((trotsky_1.StepPostReply), record);
    }
    /**
     * Appends a step to like the current post.
     *
     * @returns The appended {@link StepPostLike} instance.
     */
    like() {
        return this.append((trotsky_1.StepPostLike));
    }
    /**
     * Appends a step to repost the current post.
     *
     * @returns The appended {@link StepPostRepost} instance.
     */
    repost() {
        return this.append((trotsky_1.StepPostRepost));
    }
    /**
     * Appends a step to retrieve the author of the current post.
     *
     * @returns The appended {@link StepPostAuthor} instance.
     */
    author() {
        return this.append((trotsky_1.StepPostAuthor));
    }
}
exports.PostMixins = PostMixins;
//# sourceMappingURL=PostMixins.js.map