"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveValue = resolveValue;
/**
 * Resolves a given {@link Resolvable} input into its final value.
 * If the input is a function, it is called with the provided {@link Step} and its result is awaited.
 * Otherwise, the input is returned as is or awaited if it is a promise.
 *
 * @typeParam T - The type of the resolved value.
 * @param step - The {@link Step} instance to pass to the resolver function if the input is callable.
 * @param input - The {@link Resolvable} input to resolve.
 * @returns A promise resolving to the final value of type `T`.
 */
async function resolveValue(step, input) {
    if (typeof input === "function") {
        return await input(step);
    }
    return input;
}
//# sourceMappingURL=resolvable.js.map