"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.downloadJetstreamZstdDict = downloadJetstreamZstdDict;
const fs_1 = require("fs");
const path_1 = require("path");
const os_1 = require("os");
const https_1 = require("./https");
const JETSTREAM_ZSTD_DICT_URL = "https://raw.githubusercontent.com/bluesky-social/jetstream/main/pkg/models/zstd_dictionary";
/**
 * Downloads the Jetstream Zstandard dictionary for decompression.
 * The dictionary is saved to a temporary directory and returned as a buffer.
 *
 * @returns A promise resolving to the downloaded Zstandard dictionary as a buffer.
 */
async function downloadJetstreamZstdDict() {
    const dir = (0, fs_1.mkdtempSync)((0, path_1.join)((0, os_1.tmpdir)(), "zstd-"));
    const filepath = (0, path_1.join)(dir, "dictionary");
    return (0, https_1.downloadOnce)(JETSTREAM_ZSTD_DICT_URL, filepath);
}
//# sourceMappingURL=zstd.js.map